==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebIconDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebIconDescription } from "./WebIconDescription";
/**
 * @hidden
 */
export let WebIconDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebIconDescriptionMetadata extends Base {
        static b(a) {
            if (WebIconDescriptionMetadata.a == null) {
                WebIconDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebIconDescriptionMetadata.c(WebIconDescriptionMetadata.a);
            }
            if (a.j(WebIconDescriptionMetadata.a)) {
                return;
            }
            a.y(WebIconDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Icon");
            a.item("__tagNameWC", "String:igc-icon");
            a.item("IconName", "(wc:Name)String");
            a.item("Collection", "String");
            a.item("Mirrored", "Boolean");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
        }
        static d(a) {
            WebIconDescriptionMetadata.b(a);
            a.aa("WebIcon", () => new WebIconDescription());
            a.z("WebIcon", WebIconDescriptionMetadata.a);
        }
    }
    WebIconDescriptionMetadata.$t = /*@__PURE__*/ markType(WebIconDescriptionMetadata, 'WebIconDescriptionMetadata');
    WebIconDescriptionMetadata.a = null;
    return WebIconDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebIconDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebIconDescription } from "./WebIconDescription";
/**
 * @hidden
 */
export let WebIconDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebIconDescriptionMetadata extends Base {
        static b(a) {
            if (WebIconDescriptionMetadata.a == null) {
                WebIconDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebIconDescriptionMetadata.c(WebIconDescriptionMetadata.a);
            }
            if (a.k(WebIconDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebIconDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Icon");
            a.item("__tagNameWC", "String:igc-icon");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("IconName", "(wc:Name)String");
            a.item("Collection", "String");
            a.item("Mirrored", "Boolean");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
        }
        static d(a) {
            WebIconDescriptionMetadata.b(a);
            a.ac("WebIcon", () => new WebIconDescription());
            a.ab("WebIcon", WebIconDescriptionMetadata.a);
        }
    }
    WebIconDescriptionMetadata.$t = /*@__PURE__*/ markType(WebIconDescriptionMetadata, 'WebIconDescriptionMetadata');
    WebIconDescriptionMetadata.a = null;
    return WebIconDescriptionMetadata;
})();
